@@ -1,15 +1,15 @@
 # cards ------------------------------------------------------------------------
-#' @importFrom cards ard_continuous
+#' @importFrom cards ard_summary
 #' @export
-cards::ard_continuous
+cards::ard_summary
 
-#' @importFrom cards ard_categorical
+#' @importFrom cards ard_tabulate
 #' @export
-cards::ard_categorical
+cards::ard_tabulate
 
-#' @importFrom cards ard_dichotomous
+#' @importFrom cards ard_tabulate_value
 #' @export
-cards::ard_dichotomous
+cards::ard_tabulate_value
 
 #' @importFrom cards ard_missing
 #' @export
@@ -19,6 +19,10 @@ cards::ard_missing
 #' @export
 cards::ard_attributes
 
+#' @importFrom cards ard_total_n
+#' @export
+cards::ard_total_n
+
 # dplyr ------------------------------------------------------------------------
 #' @export
 #' @importFrom dplyr %>%
