@@ -1,4 +1,4 @@
-skip_if_not(is_pkg_installed(c("survey", "withr")))
+skip_if_pkg_not_installed(c("survey", "withr"))
 
 test_that("ard_attributes.survey.design() works", {
   withr::local_options(list(width = 120))
