@@ -1,6 +1,6 @@
-test_that("ard_continuous_ci.data.frame(method = 't.test')", {
-  skip_if_not(is_pkg_installed("broom"))
+skip_if_pkg_not_installed("broom")
 
+test_that("ard_continuous_ci.data.frame(method = 't.test')", {
   expect_equal(
     ard_continuous_ci(
       mtcars,
@@ -17,7 +17,6 @@ test_that("ard_continuous_ci.data.frame(method = 't.test')", {
 })
 
 test_that("ard_continuous_ci.data.frame(method = 'wilcox.test')", {
-  skip_if_not(is_pkg_installed("broom"))
   expect_equal(
     ard_continuous_ci(
       mtcars,
@@ -35,8 +34,6 @@ test_that("ard_continuous_ci.data.frame(method = 'wilcox.test')", {
 })
 
 test_that("ard_continuous_ci.data.frame() follows ard structure", {
-  skip_if_not(is_pkg_installed("broom"))
-
   expect_silent(
     ard_continuous_ci(
       mtcars,
