@@ -1,4 +1,4 @@
-skip_if_not(is_pkg_installed(pkg = "broom.helpers"))
+skip_if_pkg_not_installed("broom.helpers")
 
 test_that("ard_regression() works", {
   withr::local_options(list(width = 90))
@@ -38,7 +38,7 @@ test_that("ard_regression() works", {
 })
 
 test_that("ard_regression() works specifying custom tidier", {
-  skip_if_not(is_pkg_installed(pkg = c("lme4", "broom.mixed")))
+  skip_if_pkg_not_installed(c("lme4", "broom.mixed"))
   withr::local_options(list(width = 90))
 
   expect_snapshot(
@@ -58,7 +58,8 @@ test_that("ard_regression() does not produce `variable_level` column where not a
 })
 
 test_that("ard_regression() warnings and errors return correctly", {
-  skip_if_not(is_pkg_installed(pkg = "parameters"))
+  skip_if_pkg_not_installed("parameters")
+
   # constructed a model where broom.helpers fails,
   # fall back method uses parameters which returns different messaging.
   mod <- lm(AGE ~ ARM, data = cards::ADSL)
